@@ -14,6 +14,7 @@ from ginga.canvas.CanvasObject import get_canvas_types
 from ginga.canvas import render
 from ginga.misc import log
 from ginga.util.loader import load_data
+from ginga.locale.localize import _tr
 
 
 class FitsViewer(object):
@@ -28,12 +29,12 @@ class FitsViewer(object):
         self.app = Widgets.Application(logger=logger)
         self.app.add_callback('shutdown', self.quit)
         if hasattr(Widgets, 'Page'):
-            self.page = Widgets.Page("Ginga example2")
+            self.page = Widgets.Page(_tr("Ginga example2"))
             self.app.add_window(self.page)
-            self.top = Widgets.TopLevel("Ginga example2")
+            self.top = Widgets.TopLevel(_tr("Ginga example2"))
             self.page.add_dialog(self.top)
         else:
-            self.top = Widgets.TopLevel("Ginga example2")
+            self.top = Widgets.TopLevel(_tr("Ginga example2"))
             self.app.add_window(self.top)
         self.top.add_callback('close', self.closed)
 
@@ -93,15 +94,12 @@ class FitsViewer(object):
         self.readout = Widgets.Label("")
         vbox.add_widget(self.readout, stretch=0)
 
-        hbox = Widgets.HBox()
-        hbox.set_border_width(2)
-        hbox.set_spacing(4)
-
         wdrawtype = Widgets.ComboBox()
         for name in self.drawtypes:
             wdrawtype.append_text(name)
         index = self.drawtypes.index('rectangle')
         wdrawtype.set_index(index)
+        wdrawtype.set_tooltip("choose shape to draw")
         wdrawtype.add_callback('activated', lambda w, idx: self.set_drawparams())
         self.wdrawtype = wdrawtype
 
@@ -110,53 +108,97 @@ class FitsViewer(object):
             wdrawcolor.append_text(name)
         index = self.drawcolors.index('lightblue')
         wdrawcolor.set_index(index)
+        wdrawcolor.set_tooltip("choose line color")
         wdrawcolor.add_callback('activated', lambda w, idx: self.set_drawparams())
         self.wdrawcolor = wdrawcolor
 
-        wfill = Widgets.CheckBox("Fill")
-        wfill.add_callback('activated', lambda w, tf: self.set_drawparams())
-        self.wfill = wfill
+        wfillcolor = Widgets.ComboBox()
+        for name in self.drawcolors:
+            wfillcolor.append_text(name)
+        index = self.drawcolors.index('seagreen')
+        wfillcolor.set_index(index)
+        wfillcolor.set_tooltip("choose fill color")
+        wfillcolor.add_callback('activated', lambda w, idx: self.set_drawparams())
+        self.wfillcolor = wfillcolor
+
+        wwidth = Widgets.ComboBox()
+        for val in [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]:
+            wwidth.append_text(str(val))
+        wwidth.set_index(0)
+        wwidth.set_tooltip("set line width")
+        wwidth.add_callback('activated', lambda w, idx: self.set_drawparams())
+        self.wwidth = wwidth
 
         walpha = Widgets.SpinBox(dtype=float)
         walpha.set_limits(0.0, 1.0, incr_value=0.1)
         walpha.set_value(1.0)
         walpha.set_decimals(2)
+        walpha.set_tooltip("set alpha value for line")
         walpha.add_callback('value-changed', lambda w, val: self.set_drawparams())
         self.walpha = walpha
 
-        wclear = Widgets.Button("Clear Canvas")
+        wfillalpha = Widgets.SpinBox(dtype=float)
+        wfillalpha.set_limits(0.0, 1.0, incr_value=0.1)
+        wfillalpha.set_value(0.0)
+        wfillalpha.set_decimals(2)
+        wfillalpha.set_tooltip("set alpha value for fill")
+        wfillalpha.add_callback('value-changed', lambda w, val: self.set_drawparams())
+        self.wfillalpha = wfillalpha
+
+        wrender = Widgets.ComboBox()
+        for name in ['cairo', 'pil', 'agg', 'opencv', 'qt']:
+            wrender.append_text(name)
+        wrender.set_index(0)
+        wrender.set_tooltip("choose renderer backend")
+        wrender.add_callback('activated', lambda w, idx: self.set_renderer())
+        self.wrender = wrender
+
+        wclear = Widgets.Button(_tr("Clear Canvas"))
         wclear.add_callback('activated', lambda w: self.clear_canvas())
-        wopen = Widgets.Button("Open File")
+        wopen = Widgets.Button(_tr("Open File"))
         wopen.add_callback('activated', lambda w: self.open_file())
-        wquit = Widgets.Button("Quit")
+        wquit = Widgets.Button(_tr("Quit"))
         wquit.add_callback('activated', lambda w: self.quit())
 
-        hbox.add_widget(Widgets.Label(''), stretch=1)
-        for w in (wopen, wdrawtype, wdrawcolor, wfill,
-                  Widgets.Label('Alpha:'), walpha, wclear, wquit):
+        hbox = Widgets.HBox()
+        hbox.set_border_width(2)
+        hbox.set_spacing(4)
+
+        for w in (wopen, wdrawtype, wdrawcolor, wwidth,
+                  Widgets.Label(_tr('Alpha') + ':'), walpha):
             hbox.add_widget(w, stretch=0)
+        hbox.add_widget(Widgets.Label(''), stretch=1)
 
         vbox.add_widget(hbox, stretch=0)
 
+        hbox = Widgets.HBox()
+        hbox.set_border_width(2)
+        hbox.set_spacing(4)
+
+        hbox.add_widget(Widgets.Label(''), stretch=1)
+        for w in (wrender, wfillcolor, wfillalpha, wclear, wquit):
+            hbox.add_widget(w, stretch=0)
+
+        vbox.add_widget(hbox, stretch=0)
         mode = self.canvas.get_draw_mode()
         hbox = Widgets.HBox()
         hbox.set_spacing(4)
-        btn1 = Widgets.RadioButton("Draw")
+        btn1 = Widgets.RadioButton(_tr("Draw"))
         btn1.set_state(mode == 'draw')
         btn1.add_callback('activated', lambda w, val: self.set_mode_cb('draw', val))
-        btn1.set_tooltip("Choose this to draw on the canvas")
+        btn1.set_tooltip(_tr("Choose this to draw on the canvas"))
         hbox.add_widget(btn1)
 
-        btn2 = Widgets.RadioButton("Edit", group=btn1)
+        btn2 = Widgets.RadioButton(_tr("Edit"), group=btn1)
         btn2.set_state(mode == 'edit')
         btn2.add_callback('activated', lambda w, val: self.set_mode_cb('edit', val))
-        btn2.set_tooltip("Choose this to edit things on the canvas")
+        btn2.set_tooltip(_tr("Choose this to edit things on the canvas"))
         hbox.add_widget(btn2)
 
-        btn3 = Widgets.RadioButton("Pick", group=btn1)
+        btn3 = Widgets.RadioButton(_tr("Pick"), group=btn1)
         btn3.set_state(mode == 'pick')
         btn3.add_callback('activated', lambda w, val: self.set_mode_cb('pick', val))
-        btn3.set_tooltip("Choose this to pick things on the canvas")
+        btn3.set_tooltip(_tr("Choose this to pick things on the canvas"))
         hbox.add_widget(btn3)
 
         hbox.add_widget(Widgets.Label(''), stretch=1)
@@ -172,29 +214,40 @@ class FitsViewer(object):
         index = self.wdrawtype.get_index()
         kind = self.drawtypes[index]
         index = self.wdrawcolor.get_index()
-        fill = self.wfill.get_state()
+        linewidth = int(self.wwidth.get_text())
         alpha = self.walpha.get_value()
+        fillalpha = self.wfillalpha.get_value()
 
         params = {'color': self.drawcolors[index],
+                  'linewidth': linewidth,
                   'alpha': alpha,
                   }
         if kind in ('circle', 'rectangle', 'polygon', 'triangle',
                     'righttriangle', 'ellipse', 'square', 'box'):
-            params['fill'] = fill
-            params['fillalpha'] = alpha
+            params['fill'] = True
+            index = self.wfillcolor.get_index()
+            params['fillcolor'] = self.drawcolors[index]
+            params['fillalpha'] = fillalpha
 
         self.canvas.set_drawtype(kind, **params)
 
     def clear_canvas(self):
         self.canvas.delete_all_objects()
 
+    def set_renderer(self):
+        name = self.wrender.get_text()
+        klass = render.get_render_class(name)
+        renderer = klass(self.fitsimage)
+        self.fitsimage.set_renderer(renderer)
+        self.fitsimage.redraw(whence=0)
+
     def load_file(self, filepath):
         image = load_data(filepath, logger=self.logger)
         self.fitsimage.set_image(image)
         self.top.set_title(filepath)
 
     def open_file(self):
-        self.fs.popup("Open FITS file", self.load_file)
+        self.fs.popup(_tr("Open FITS file"), self.load_file)
 
     def drop_file_cb(self, viewer, paths):
         filename = paths[0]
@@ -226,10 +279,10 @@ class FitsViewer(object):
             ra_txt, dec_txt = image.pixtoradec(fits_x, fits_y,
                                                format='str', coords='fits')
         except Exception as e:
-            self.logger.warning("Bad coordinate conversion: %s" % (
+            self.logger.warning(_tr("Bad coordinate conversion") + ": %s" % (
                 str(e)))
-            ra_txt = 'BAD WCS'
-            dec_txt = 'BAD WCS'
+            ra_txt = _tr('BAD WCS')
+            dec_txt = _tr('BAD WCS')
 
         text = "RA: %s  DEC: %s  X: %.2f  Y: %.2f  Value: %s" % (
             ra_txt, dec_txt, fits_x, fits_y, value)
