@@ -282,14 +282,8 @@ class MDISubWindow(Callback.Callbacks):
 
         vbox = Gtk.VBox()
         vbox.set_border_width(4)
-        hbox = Gtk.HBox()
-        close = Gtk.Button("x")
-        maxim = Gtk.Button("^")
-        minim = Gtk.Button("v")
-        hbox.pack_start(close, False, False, 0)
-        hbox.pack_start(minim, False, False, 0)
-        hbox.pack_start(maxim, False, False, 0)
 
+        hbox = Gtk.HBox()
         evbox = Gtk.EventBox()
         evbox.add(label)
         modify_bg(evbox, "gray90")
@@ -297,6 +291,13 @@ class MDISubWindow(Callback.Callbacks):
         self.evbox = evbox
         hbox.pack_start(evbox, True, True, 2)
 
+        close = Gtk.Button("X")
+        maxim = Gtk.Button("^")
+        minim = Gtk.Button("_")
+        hbox.pack_start(minim, False, False, 0)
+        hbox.pack_start(maxim, False, False, 0)
+        hbox.pack_start(close, False, False, 0)
+
         vbox.pack_start(hbox, False, False, 0)
         vbox.pack_start(widget, True, True, 4)
 
@@ -786,10 +787,10 @@ class Splitter(Gtk.Layout):
 
         else:
             if self.orientation == 'horizontal':
-                thumbfile, _w, _h = ('vdots.png', self.thumb_px,
+                thumbfile, _w, _h = ('vdots.svg', self.thumb_px,
                                      int(self.thumb_px * self.thumb_aspect))
             else:
-                thumbfile, _w, _h = ('hdots.png',
+                thumbfile, _w, _h = ('hdots.svg',
                                      int(self.thumb_px * self.thumb_aspect),
                                      self.thumb_px)
             iconfile = os.path.join(icondir, thumbfile)
@@ -1693,11 +1694,19 @@ def get_scroll_info(event):
     return (num_degrees, direction)
 
 
-def get_icon(iconpath, size=None):
+def get_icon(iconpath, size=None, adjust_width=True):
     if size is not None:
         wd, ht = size
     else:
         wd, ht = 24, 24
+
+    if adjust_width:
+        pixbuf = pixbuf_new_from_file(iconpath)
+        # get "natural" dimensions
+        _w, _h = pixbuf.get_width(), pixbuf.get_height()
+        aspect = _w / _h
+        wd = int(wd * aspect)
+
     pixbuf = pixbuf_new_from_file_at_size(iconpath, wd, ht)
     return pixbuf
 
@@ -1748,10 +1757,10 @@ def pixbuf_new_from_file(file_path):
     return GdkPixbuf.Pixbuf.new_from_file(file_path)
 
 
-def make_cursor(widget, iconpath, x, y):
-    image = Gtk.Image()
-    image.set_from_file(iconpath)
-    pixbuf = image.get_pixbuf()
+def make_cursor(widget, iconpath, x, y, size=None):
+    if size is None:
+        size = (16, 16)
+    pixbuf = get_icon(iconpath, size=size, adjust_width=False)
     screen = widget.get_screen()
     display = screen.get_display()
     return Gdk.Cursor(display, pixbuf, x, y)
@@ -1787,5 +1796,3 @@ def set_default_style():
 
     except Exception:
         pass
-
-# END
