@@ -18,33 +18,16 @@ from gi.repository import Gdk
 from gi.repository import GObject
 from gi.repository import GdkPixbuf
 
-import gi
-has_webkit = False
-
-try:
-    # this is necessary to prevent a warning message on import
-    gi.require_version('WebKit2', '4.0')
-
-    from gi.repository import WebKit2 as WebKit  # noqa
-    has_webkit = True
-except Exception:
-    try:
-        gi.require_version('WebKit', '3.0')
-        from gi.repository import WebKit  # noqa
-    except Exception:
-        pass
-
 __all__ = ['WidgetError', 'WidgetBase', 'TextEntry', 'TextEntrySet',
            'TextArea', 'Label', 'Button', 'ComboBox',
            'SpinBox', 'Slider', 'Dial', 'ScrollBar', 'CheckBox', 'ToggleButton',
            'RadioButton', 'Image', 'ProgressBar', 'StatusBar', 'TreeView',
-           'WebView', 'ContainerBase', 'Box', 'HBox', 'VBox', 'Frame',
+           'ContainerBase', 'Box', 'HBox', 'VBox', 'Frame',
            'Expander', 'TabWidget', 'StackWidget', 'MDIWidget', 'ScrollArea',
            'Splitter', 'GridBox', 'Toolbar', 'MenuAction',
            'Menu', 'Menubar', 'TopLevelMixin', 'TopLevel', 'Application',
            'Dialog', 'SaveDialog', 'DragPackage', 'WidgetMoveEvent',
-           'name_mangle', 'make_widget', 'hadjust', 'build_info', 'wrap',
-           'has_webkit']
+           'name_mangle', 'make_widget', 'hadjust', 'build_info', 'wrap']
 
 # path to our icons
 icondir = os.path.split(ginga.icons.__file__)[0]
@@ -1161,33 +1144,6 @@ class TreeView(WidgetBase):
         drag_pkg.start_drag()
 
 
-class WebView(WidgetBase):
-    def __init__(self):
-        if not has_webkit:
-            raise NotImplementedError("Missing webkit")
-
-        super(WebView, self).__init__()
-        self.widget = WebKit.WebView()
-
-    def load_url(self, url):
-        self.widget.open(url)
-
-    def load_html_string(self, html_string):
-        self.widget.load_string(html_string, 'text/html', 'utf-8', 'file://')
-
-    def go_back(self):
-        self.widget.go_back()
-
-    def go_forward(self):
-        self.widget.go_forward()
-
-    def reload_page(self):
-        self.widget.reload()
-
-    def stop_loading(self):
-        self.widget.stop_loading()
-
-
 # CONTAINERS
 
 class ContainerBase(WidgetBase):
@@ -1320,11 +1276,11 @@ class Expander(ContainerBase):
         self.widget = vbox.get_widget()
         self._vbox = vbox
         if Expander.r_arrow is None:
-            iconpath = os.path.join(icondir, 'triangle-right-48.png')
+            iconpath = os.path.join(icondir, 'triangle-right.svg')
             Expander.r_arrow = GtkHelp.pixbuf_new_from_file_at_size(iconpath,
                                                                     12, 12)
         if Expander.d_arrow is None:
-            iconpath = os.path.join(icondir, 'triangle-down-48.png')
+            iconpath = os.path.join(icondir, 'triangle-down.svg')
             Expander.d_arrow = GtkHelp.pixbuf_new_from_file_at_size(iconpath,
                                                                     12, 12)
         self._d_arrow = Gtk.Image.new_from_pixbuf(Expander.d_arrow)
@@ -2375,7 +2331,7 @@ class Application(Callback.Callbacks):
         GObject.threads_init()
         # self._time_save = time.time()
 
-        for name in ('shutdown', ):
+        for name in ('close', 'shutdown'):
             self.enable_callback(name)
 
         # Set up Gtk style
@@ -2435,7 +2391,20 @@ class Application(Callback.Callbacks):
     def mainloop(self):
         Gtk.main()
 
+    def close(self):
+        """Called when someone is asking the application to close.
+        Can register for this callback if you want an application-wide
+        event to confirm closure.
+        """
+        self.make_callback('close')
+
     def quit(self):
+        """Called when someone is forcibly quitting the application.
+        Can register for this callback if you want an application-wide
+        event to clean up before shutdown.
+        """
+        self.make_callback('shutdown')
+
         Gtk.main_quit()
 
 
@@ -2444,18 +2413,28 @@ class Dialog(TopLevelMixin, WidgetBase):
     def __init__(self, title='', flags=0, buttons=[],
                  parent=None, modal=False):
         WidgetBase.__init__(self)
+        self.buttons = []
 
         if parent is not None:
             self.parent = parent.get_widget()
         else:
             self.parent = None
 
-        button_list = []
+        self.widget = Gtk.Dialog(title=title, flags=flags)
+        btn_box = Gtk.ButtonBox()
+        btn_box.set_border_width(5)
+        btn_box.set_spacing(4)
+
         for name, val in buttons:
-            button_list.extend([name, val])
+            btn = Button(name)
+            self.buttons.append(btn)
+
+            def cb(val):
+                return lambda w: self._cb_redirect(val)
+
+            btn.add_callback('activated', cb(val))
+            btn_box.pack_start(btn.get_widget(), True, True, 0)
 
-        self.widget = Gtk.Dialog(title=title, flags=flags,
-                                 buttons=tuple(button_list))
         self.widget.set_modal(modal)
 
         TopLevelMixin.__init__(self, title=title)
@@ -2464,12 +2443,13 @@ class Dialog(TopLevelMixin, WidgetBase):
         self.content.set_border_width(0)
         content = self.widget.get_content_area()
         content.pack_start(self.content.get_widget(), True, True, 0)
+        content.pack_end(btn_box, True, True, 0)
 
-        self.widget.connect("response", self._cb_redirect)
+        #self.widget.connect("response", self._cb_redirect)
 
         self.enable_callback('activated')
 
-    def _cb_redirect(self, w, val):
+    def _cb_redirect(self, val):
         self.make_callback('activated', val)
 
     def get_content_area(self):
@@ -2565,14 +2545,14 @@ def make_widget(title, wtype):
     elif wtype == 'llabel':
         w = Label(title)
         w.label.set_alignment(0.05, 0.95)
-    elif wtype == 'entry':
+    elif wtype in ('textentry', 'entry'):
         w = TextEntry()
         # w.get_widget().set_width_chars(12)
-    elif wtype == 'entryset':
+    elif wtype in ('textentryset', 'entryset'):
         w = TextEntrySet()
     elif wtype == 'combobox':
         w = ComboBox()
-    elif wtype == 'spinbutton':
+    elif wtype in ('spinbox', 'spinbutton'):
         w = SpinBox(dtype=int)
     elif wtype == 'spinfloat':
         w = SpinBox(dtype=float)
