@@ -7,6 +7,9 @@
 import time
 import math
 import os.path
+import uuid
+
+import yaml
 
 from ginga.misc import Bunch, Callback
 from ginga.gw import Widgets, Viewers
@@ -22,7 +25,6 @@ class Desktop(Callback.Callbacks):
         self.logger = app.logger
         # for tabs
         self.tab = Bunch.caselessDict()
-        self.tabcount = 0
         self.workspace = Bunch.caselessDict()
         self.default_ws_name = None
 
@@ -101,9 +103,26 @@ class Desktop(Callback.Callbacks):
                 res.append(name)
         return res
 
-    def get_tabnames(self, group=1):
+    def _get_unique_name(self):
+        return '_uniq_' + str(uuid.uuid4())
+
+    def get_tabnames(self, group=1, unique=False):
+        """Return a list of all tab names.
+
+        Parameters
+        ----------
+        group : int (optional, defaults to 1)
+            Only return tabs that belong to a certain group.
+
+        unique : bool (optional, defaults to False)
+            If True, return the unique (coded) tab names,
+            otherwise returns regular tab names (which will not
+            include duplicate names).
+        """
         res = []
         for name in self.tab.keys():
+            if unique != (name.startswith('_uniq_')):
+                continue
             bnch = self.tab[name]
             if group is None:
                 res.append(name)
@@ -111,31 +130,66 @@ class Desktop(Callback.Callbacks):
                 res.append(name)
         return res
 
+    def add_widget_as_toplevel(self, title, widget, data=None):
+        topw = widget.get_app().make_window()
+        topw.set_title(title)
+        topw.set_widget(widget)
+        topw.show()
+
+        bnch = Bunch.Bunch(widget=widget, name=title,
+                           enclosure='toplevel', parent=topw,
+                           tabname=title, data=data,
+                           uniqname=self._get_unique_name(),
+                           group=1, wsname=None)
+        if title not in self.tab:
+            self.tab[title] = bnch
+        self.tab[bnch.uniqname] = bnch
+        return bnch
+
+    def add_widget_as_dialog(self, title, widget, data=None):
+        dialog = Widgets.Dialog(title=title,
+                                flags=0,
+                                buttons=[],
+                                parent=self.app.w.root)
+        box = dialog.get_content_area()
+        box.add_widget(widget, stretch=1)
+        dialog.show()
+
+        bnch = Bunch.Bunch(widget=widget, name=title,
+                           enclosure='dialog', parent=dialog,
+                           tabname=title, data=data,
+                           uniqname=self._get_unique_name(),
+                           group=1, wsname=None)
+        if title not in self.tab:
+            self.tab[title] = bnch
+        self.tab[bnch.uniqname] = bnch
+        return bnch
+
     def add_tab(self, wsname, widget, group, labelname, tabname=None,
                 data=None):
         ws = self.get_ws(wsname)
-        self.tabcount += 1
         if not tabname:
             tabname = labelname
-            if tabname in self.tab:
-                tabname = 'tab%d' % self.tabcount
 
         ws.add_tab(widget, title=labelname)
         bnch = Bunch.Bunch(widget=widget, name=labelname,
+                           enclosure='workspace', workspace=ws,
                            tabname=tabname, data=data,
+                           uniqname=self._get_unique_name(),
                            group=group, wsname=wsname)
-        self.tab[tabname] = bnch
+        if tabname not in self.tab:
+            self.tab[tabname] = bnch
+        self.tab[bnch.uniqname] = bnch
         return bnch
 
     def _find_nb(self, tabname):
-        widget = self.tab[tabname].widget
-        for ws in self.workspace.values():
-            nb = ws.nb
-            page_num = nb.index_of(widget)
-            if page_num < 0:
-                continue
-            return (nb, page_num)
-        return (None, None)
+        if tabname not in self.tab:
+            return (None, None)
+        bnch = self.tab[tabname]
+        page_num = bnch.workspace.nb.index_of(bnch.widget)
+        if page_num < 0:
+            return (None, None)
+        return (bnch.workspace.nb, page_num)
 
     def _find_tab(self, widget):
         for key, bnch in self.tab.items():
@@ -143,6 +197,15 @@ class Desktop(Callback.Callbacks):
                 return bnch
         return None
 
+    def _cleanup_tab(self, widget):
+        """Clean up our tabs table after a tab or window has been deleted."""
+        found = []
+        for key, bnch in self.tab.items():
+            if widget == bnch.widget:
+                found.append(key)
+        for key in found:
+            del self.tab[key]
+
     def raise_tab(self, tabname):
         # construct a list of the tabs to raise in the order they
         # should be raised
@@ -150,6 +213,8 @@ class Desktop(Callback.Callbacks):
         name = tabname.lower()
         while name in self.tab:
             bnch = self.tab[name]
+            if bnch.wsname is None:
+                break
             l.insert(0, name)
             name = bnch.wsname.lower()
             if name in l:
@@ -165,8 +230,8 @@ class Desktop(Callback.Callbacks):
         nb, index = self._find_nb(tabname)
         widget = self.tab[tabname].widget
         if (nb is not None) and (index >= 0):
-            del self.tab[tabname]
             nb.remove(widget)
+        self._cleanup_tab(widget)
 
     def highlight_tab(self, tabname, onoff):
         nb, index = self._find_nb(tabname)
@@ -696,15 +761,13 @@ class Desktop(Callback.Callbacks):
 
         self.record_sizes()
 
-        _n, ext = os.path.splitext(lo_file)
         # write layout
+        _n, ext = os.path.splitext(lo_file)
         with open(lo_file, 'w') as out_f:
-            if ext.lower() == '.json':
-                out_f.write(json.dumps(layout, indent=2))
+            if ext.lower() in ['.yml', '.yaml']:
+                out_f.write(yaml.dump(layout, indent=2))
             else:
-                # older, python format
-                import pprint
-                pprint.pprint(layout, out_f)
+                out_f.write(json.dumps(layout, indent=2))
 
     def read_layout_conf(self, lo_file):
         # read layout
@@ -712,12 +775,10 @@ class Desktop(Callback.Callbacks):
             buf = in_f.read()
 
         _n, ext = os.path.splitext(lo_file)
-        if ext.lower() == '.json':
-            layout = json.loads(buf)
+        if ext.lower() in ['.yml', '.yaml']:
+            layout = yaml.safe_load(buf)
         else:
-            # older, python format
-            import ast
-            layout = ast.literal_eval(buf)
+            layout = json.loads(buf)
         return layout
 
     def build_desktop(self, layout, lo_file=None, widget_dict=None):
@@ -884,12 +945,25 @@ class Workspace(Widgets.WidgetBase):
 
         self.vbox.remove(old_widget)
 
+        old_wstype = self.wstype
         self._set_wstype(wstype)
         self.vbox.add_widget(self.nb, stretch=1)
 
         for child in list(old_widget.get_children()):
             # TODO: sort by previous index so they get added to the
             # new widget in the same order
+            if old_wstype == 'mdi':
+                # record MDI window size and position if we are leaving
+                # an MDI configuration
+                child.extdata.mdi_size = child.get_size()
+                child.extdata.mdi_pos = child.get_pos()
+            if self.wstype == 'mdi':
+                # if entering an MDI configuration and we don't have
+                # previously saved size then set it to the current size
+                if child.extdata.get('mdi_size', None) is None:
+                    child.extdata.mdi_size = child.get_size()
+                    child.extdata.mdi_pos = child.get_pos()
+
             title = child.extdata.get('tab_title', '')
             child.hide()
             old_widget.remove(child)
