@@ -7,9 +7,6 @@ tkname = toolkit.get_family()
 if tkname == 'qt':
     from ginga.qtw.QtHelp import *  # noqa
 
-elif tkname == 'gtk':
-    from ginga.gtkw.GtkHelp import *  # noqa
-
 elif tkname == 'gtk3':
     from ginga.gtk3w.GtkHelp import *  # noqa
 
