@@ -40,6 +40,8 @@ class PluginManager(Callback.Callbacks):
             self.enable_callback(name)
 
     def load_plugin(self, name, spec, chinfo=None):
+        if not spec.get('enabled', True):
+            return
         try:
             module = self.mm.get_module(spec.module)
             className = spec.get('klass', spec.module)
@@ -61,6 +63,7 @@ class PluginManager(Callback.Callbacks):
                                               widget=None, name=name,
                                               is_toplevel=False,
                                               spec=spec,
+                                              wsname=None,
                                               fitsimage=fitsimage,
                                               chinfo=chinfo)
 
@@ -253,7 +256,7 @@ class PluginManager(Callback.Callbacks):
                                         alreadyOpenOk=alreadyOpenOk)
 
     def start_plugin_future(self, chname, opname, future,
-                            alreadyOpenOk=True):
+                            alreadyOpenOk=True, wsname=None):
         try:
             p_info = self.get_plugin_info(opname)
 
@@ -288,10 +291,14 @@ class PluginManager(Callback.Callbacks):
             if hasattr(p_info.obj, 'build_gui'):
                 vbox = Widgets.VBox()
 
-                in_ws = p_info.spec.get('workspace', None)
-                if in_ws is None:
-                    # to be deprecated
-                    in_ws = p_info.spec.ws
+                if wsname is None:
+                    in_ws = p_info.spec.get('workspace', None)
+                    if in_ws is None:
+                        # to be deprecated
+                        in_ws = p_info.spec.ws
+                else:
+                    in_ws = wsname
+                p_info.wsname = wsname
 
                 if in_ws.startswith('in:'):
                     # TODO: how to set this size appropriately
@@ -366,21 +373,32 @@ class PluginManager(Callback.Callbacks):
     def stop_plugin(self, p_info):
         self.logger.debug("stopping plugin %s" % (str(p_info)))
         wasError = False
-        e = None
+        _err = None
         try:
             p_info.obj.stop()
 
         except Exception as e:
-            wasError = True
+            wasError, _err = True, e
             self.logger.error("Plugin '{}' failed to stop correctly: {}".format(p_info.name, e),
                               exc_info=True)
 
         if p_info.widget is not None:
-            self.dispose_gui(p_info)
-            self.ds.remove_tab(p_info.tabname)
+            # if there was a GUI built for this plugin, remove it
+            try:
+                if p_info.wsname is not None:
+                    ws = self.ds.get_ws(p_info.wsname)
+                    ws.remove_tab(p_info.widget)
+                elif not p_info.is_toplevel:
+                    self.ds.remove_tab(p_info.tabname)
+                self.dispose_gui(p_info)
+
+            except Exception as e:
+                wasError, _err = True, e
+                self.logger.error("Plugin UI for '{}' wasn't closed correctly: {}".format(p_info.name, e),
+                                  exc_info=True)
 
         if wasError:
-            raise PluginManagerError(e)
+            raise PluginManagerError(_err)
 
     def stop_all_plugins(self):
         for plugin_name in self.get_active():
@@ -403,35 +421,33 @@ class PluginManager(Callback.Callbacks):
         wd, ht = vbox.get_size()
 
         try:
-            in_ws = p_info.spec.get('workspace', None)
+            in_ws = p_info.wsname
             if in_ws is None:
-                # to be deprecated
-                in_ws = p_info.spec.ws
+                in_ws = p_info.spec.get('workspace', None)
+                if in_ws is None:
+                    in_ws = 'in:toplevel'
 
             if in_ws == 'in:toplevel':
-                topw = vbox.get_app().make_window()
+                bnch = self.ds.add_widget_as_toplevel(p_info.tabname, vbox)
+                bnch.plugin_info = p_info
+                topw = bnch.parent
                 topw.add_callback('close',
                                   lambda *args: self.deactivate(p_info.name))
-                topw.resize(wd, ht)
-                topw.set_title(p_info.tabname)
-                topw.set_widget(vbox)
+                # NOTE: for now, let toplevel window be it's "natural size"
+                # topw.resize(wd, ht)
                 p_info.widget = topw
                 p_info.is_toplevel = True
-                topw.show()
 
             elif in_ws == 'in:dialog':
-                dialog = Widgets.Dialog(title=p_info.name,
-                                        flags=0,
-                                        buttons=[],
-                                        parent=self.fv.w.root)
-                dialog.resize(wd, ht)
-                box = dialog.get_content_area()
-                box.add_widget(vbox, stretch=1)
+                bnch = self.ds.add_widget_as_dialog(p_info.tabname, vbox)
+                bnch.plugin_info = p_info
+                dialog = bnch.parent
+                dialog.add_callback('close',
+                                    lambda *args: self.deactivate(p_info.name))
+                # NOTE: for now, let dialog window be it's "natural size"
+                #dialog.resize(wd, ht)
                 p_info.widget = dialog
                 p_info.is_toplevel = True
-                # TODO: need to add callback to remove from Desktop
-                # dialog list?
-                self.ds.show_dialog(dialog)
 
             else:
                 bnch = self.ds.add_tab(in_ws, vbox, 2, p_info.tabname,
@@ -447,8 +463,10 @@ class PluginManager(Callback.Callbacks):
                 p_info.is_toplevel = False
 
         except Exception as e:
-            self.fv.show_error("Error finishing plugin UI for '%s': %s" % (
-                p_info.name, str(e)))
+            errmsg = "Error finishing plugin UI for '%s': %s" % (
+                p_info.name, str(e))
+            self.logger.error(errmsg, exc_info=True)
+            self.fv.show_error(errmsg)
 
     def tab_switched_cb(self, tab_w, widget):
         # A tab in a workspace in which we started a plugin has been
@@ -490,6 +508,7 @@ class PluginManager(Callback.Callbacks):
     def dispose_gui(self, p_info):
         self.logger.debug("disposing of gui")
         vbox = p_info.widget
+        self.ds._cleanup_tab(vbox)
         p_info.widget = None
         vbox.hide()
         vbox.delete()
