@@ -34,7 +34,8 @@ class RenderContext(render.RenderContextBase):
         alpha = getattr(shape, 'alpha', 1.0)
         linewidth = getattr(shape, 'linewidth', 1.0)
         linestyle = getattr(shape, 'linestyle', 'solid')
-        self.pen = self.cr.get_pen(shape.color, linewidth=linewidth,
+        color = getattr(shape, 'color', 'black')
+        self.pen = self.cr.get_pen(color, linewidth=linewidth,
                                    linestyle=linestyle, alpha=alpha)
 
     def set_fill_from_shape(self, shape):
