@@ -152,8 +152,11 @@ class Vector3D(object):
 
 class Matrix4x4(object):
 
-    def __init__(self):
-        self.set_to_identity()
+    def __init__(self, arr4x4=None):
+        if arr4x4 is None:
+            self.m = np.eye(4)
+        else:
+            self.m = np.asarray(arr4x4).reshape((4, 4))
 
     def __str__(self):
         return str(self.m)
@@ -166,9 +169,7 @@ class Matrix4x4(object):
         return self.m
 
     def copy(self):
-        M = Matrix4x4()
-        M.m = self.m.copy()
-        return M
+        return Matrix4x4(self.m)
 
     def set_to_identity(self):
         self.m = np.eye(4)
@@ -176,9 +177,10 @@ class Matrix4x4(object):
     @staticmethod
     def translation(vector3D):
         M = Matrix4x4()
-        M.f[12] = vector3D.x
-        M.f[13] = vector3D.y
-        M.f[14] = vector3D.z
+        ## M.f[12] = vector3D.x
+        ## M.f[13] = vector3D.y
+        ## M.f[14] = vector3D.z
+        M.f[12:15] = vector3D.coord
         return M
 
     @staticmethod
@@ -187,30 +189,21 @@ class Matrix4x4(object):
         c = np.cos(angle_rad)
         s = np.sin(angle_rad)
         one_minus_c = 1 - c
-        M = Matrix4x4()
-        M.f[0] = c + one_minus_c * axis_vector.x * axis_vector.x
-        M.f[5] = c + one_minus_c * axis_vector.y * axis_vector.y
-        M.f[10] = c + one_minus_c * axis_vector.z * axis_vector.z
-        M.f[1] = M.f[4] = one_minus_c * axis_vector.x * axis_vector.y
-        M.f[2] = M.f[8] = one_minus_c * axis_vector.x * axis_vector.z
-        M.f[6] = M.f[9] = one_minus_c * axis_vector.y * axis_vector.z
+
+        c0 = c + one_minus_c * axis_vector.x * axis_vector.x
+        c1 = one_minus_c * axis_vector.x * axis_vector.y
+        c2 = one_minus_c * axis_vector.x * axis_vector.z
+        c3 = c + one_minus_c * axis_vector.y * axis_vector.y
+        c4 = one_minus_c * axis_vector.y * axis_vector.z
+        c5 = c + one_minus_c * axis_vector.z * axis_vector.z
         xs = axis_vector.x * s
         ys = axis_vector.y * s
         zs = axis_vector.z * s
-        M.f[1] += zs
-        M.f[4] -= zs
-        M.f[2] -= ys
-        M.f[8] += ys
-        M.f[6] += xs
-        M.f[9] -= xs
 
-        M.f[12] = 0.0
-        M.f[13] = 0.0
-        M.f[14] = 0.0
-        M.f[3] = 0.0
-        M.f[7] = 0.0
-        M.f[11] = 0.0
-        M.f[15] = 1.0
+        M = Matrix4x4((c0, c1 + zs, c2 - ys, 0.0,
+                       c1 - zs, c3, c4 + xs, 0.0,
+                       c2 + ys, c4 - xs, c5, 0.0,
+                       0.0, 0.0, 0.0, 1.0))
         return M
 
     @staticmethod
@@ -244,48 +237,22 @@ class Matrix4x4(object):
         x = x.normalized()
         y = y.normalized()
 
-        M = Matrix4x4()
-
         if is_inverted:
             # the rotation matrix
-            M.f[0] = x.x
-            M.f[4] = y.x
-            M.f[8] = z.x
-            M.f[12] = 0.0
-            M.f[1] = x.y
-            M.f[5] = y.y
-            M.f[9] = z.y
-            M.f[13] = 0.0
-            M.f[2] = x.z
-            M.f[6] = y.z
-            M.f[10] = z.z
-            M.f[14] = 0.0
-            M.f[3] = 0.0
-            M.f[7] = 0.0
-            M.f[11] = 0.0
-            M.f[15] = 1.0
+            M = Matrix4x4((x.x, x.y, x.z, 0.0,
+                           y.x, y.y, y.z, 0.0,
+                           z.x, z.y, z.z, 0.0,
+                           0.0, 0.0, 0.0, 1.0))
 
             # step two: premultiply by a translation matrix
             return Matrix4x4.translation(eye_point.as_Vector3D()) * M
 
         else:
             # the rotation matrix
-            M.f[0] = x.x
-            M.f[4] = x.y
-            M.f[8] = x.z
-            M.f[12] = 0.0
-            M.f[1] = y.x
-            M.f[5] = y.y
-            M.f[9] = y.z
-            M.f[13] = 0.0
-            M.f[2] = z.x
-            M.f[6] = z.y
-            M.f[10] = z.z
-            M.f[14] = 0.0
-            M.f[3] = 0.0
-            M.f[7] = 0.0
-            M.f[11] = 0.0
-            M.f[15] = 1.0
+            M = Matrix4x4((x.x, y.x, z.x, 0.0,
+                           x.y, y.y, z.y, 0.0,
+                           x.z, y.z, z.z, 0.0,
+                           0.0, 0.0, 0.0, 1.0))
 
             # step two: postmultiply by a translation matrix
             return M * Matrix4x4.translation(- eye_point.as_Vector3D())
@@ -293,42 +260,7 @@ class Matrix4x4(object):
     def __mul__(self, b):
         a = self
         if isinstance(b, Matrix4x4):
-            M = Matrix4x4()
-            M.f[0] = (a.f[0] * b.f[0] + a.f[4] * b.f[1] +
-                      a.f[8] * b.f[2] + a.f[12] * b.f[3])
-            M.f[1] = (a.f[1] * b.f[0] + a.f[5] * b.f[1] +
-                      a.f[9] * b.f[2] + a.f[13] * b.f[3])
-            M.f[2] = (a.f[2] * b.f[0] + a.f[6] * b.f[1] +
-                      a.f[10] * b.f[2] + a.f[14] * b.f[3])
-            M.f[3] = (a.f[3] * b.f[0] + a.f[7] * b.f[1] +
-                      a.f[11] * b.f[2] + a.f[15] * b.f[3])
-
-            M.f[4] = (a.f[0] * b.f[4] + a.f[4] * b.f[5] +
-                      a.f[8] * b.f[6] + a.f[12] * b.f[7])
-            M.f[5] = (a.f[1] * b.f[4] + a.f[5] * b.f[5] +
-                      a.f[9] * b.f[6] + a.f[13] * b.f[7])
-            M.f[6] = (a.f[2] * b.f[4] + a.f[6] * b.f[5] +
-                      a.f[10] * b.f[6] + a.f[14] * b.f[7])
-            M.f[7] = (a.f[3] * b.f[4] + a.f[7] * b.f[5] +
-                      a.f[11] * b.f[6] + a.f[15] * b.f[7])
-
-            M.f[8] = (a.f[0] * b.f[8] + a.f[4] * b.f[9] +
-                      a.f[8] * b.f[10] + a.f[12] * b.f[11])
-            M.f[9] = (a.f[1] * b.f[8] + a.f[5] * b.f[9] +
-                      a.f[9] * b.f[10] + a.f[13] * b.f[11])
-            M.f[10] = (a.f[2] * b.f[8] + a.f[6] * b.f[9] +
-                       a.f[10] * b.f[10] + a.f[14] * b.f[11])
-            M.f[11] = (a.f[3] * b.f[8] + a.f[7] * b.f[9] +
-                       a.f[11] * b.f[10] + a.f[15] * b.f[11])
-
-            M.f[12] = (a.f[0] * b.f[12] + a.f[4] * b.f[13] +
-                       a.f[8] * b.f[14] + a.f[12] * b.f[15])
-            M.f[13] = (a.f[1] * b.f[12] + a.f[5] * b.f[13] +
-                       a.f[9] * b.f[14] + a.f[13] * b.f[15])
-            M.f[14] = (a.f[2] * b.f[12] + a.f[6] * b.f[13] +
-                       a.f[10] * b.f[14] + a.f[14] * b.f[15])
-            M.f[15] = (a.f[3] * b.f[12] + a.f[7] * b.f[13] +
-                       a.f[11] * b.f[14] + a.f[15] * b.f[15])
+            M = Matrix4x4(np.dot(b.m, a.m))
             return M
 
         elif isinstance(b, Vector3D):
