@@ -9,30 +9,22 @@ import pathlib
 from functools import reduce
 
 from ginga.qtw.QtHelp import (QtGui, QtCore, QTextCursor, QIcon, QPixmap,
-                              QImage, QCursor, QFont)
+                              QCursor, QFont)
 from ginga.qtw import QtHelp
 
 from ginga.misc import Callback, Bunch, Settings, LineHistory
 from ginga.util.paths import icondir
 
-has_webkit = False
-try:
-    from ginga.qtw.QtHelp import QWebView  # noqa
-    has_webkit = True
-except ImportError:
-    pass
-
 __all__ = ['WidgetError', 'WidgetBase', 'TextEntry', 'TextEntrySet',
            'GrowingTextEdit', 'TextArea', 'Label', 'Button', 'ComboBox',
            'SpinBox', 'Slider', 'Dial', 'ScrollBar', 'CheckBox', 'ToggleButton',
            'RadioButton', 'Image', 'ProgressBar', 'StatusBar', 'TreeView',
-           'WebView', 'ContainerBase', 'Box', 'HBox', 'VBox', 'Frame',
+           'ContainerBase', 'Box', 'HBox', 'VBox', 'Frame',
            'Expander', 'TabWidget', 'StackWidget', 'MDIWidget', 'ScrollArea',
            'Splitter', 'GridBox', 'ToolbarAction', 'Toolbar', 'MenuAction',
            'Menu', 'Menubar', 'TopLevelMixin', 'TopLevel', 'Application',
            'Dialog', 'SaveDialog', 'DragPackage',
-           'name_mangle', 'make_widget', 'hadjust', 'build_info', 'wrap',
-           'has_webkit']
+           'name_mangle', 'make_widget', 'hadjust', 'build_info', 'wrap']
 
 
 class WidgetError(Exception):
@@ -88,7 +80,12 @@ class WidgetBase(Callback.Callbacks):
         # self.widget.raise_()
 
     def resize(self, width, height):
-        self.widget.resize(width, height)
+        _wd, _ht = self.get_size()
+        if width < 0:
+            width = _wd
+        if height < 0:
+            height = _ht
+        self.widget.resize(int(width), int(height))
 
     def show(self):
         self.widget.show()
@@ -318,7 +315,11 @@ class Label(WidgetBase):
             menu_w = menu.get_widget()
 
             def on_context_menu(point):
-                menu_w.exec(lbl.mapToGlobal(point))
+                if hasattr(menu_w, 'exec_'):
+                    # PySide2
+                    menu_w.exec_(lbl.mapToGlobal(point))
+                else:
+                    menu_w.exec(lbl.mapToGlobal(point))
 
             lbl.customContextMenuRequested.connect(on_context_menu)
 
@@ -699,7 +700,11 @@ class Image(WidgetBase):
             menu_w = menu.get_widget()
 
             def on_context_menu(point):
-                menu_w.exec(lbl.mapToGlobal(point))
+                if hasattr(menu_w, 'exec_'):
+                    # PySide2
+                    menu_w.exec_(lbl.mapToGlobal(point))
+                else:
+                    menu_w.exec(lbl.mapToGlobal(point))
 
             lbl.customContextMenuRequested.connect(on_context_menu)
 
@@ -953,7 +958,11 @@ class TreeView(WidgetBase):
         self.shadow = {}
 
     def clear_selection(self):
-        self.widget.clearSelection()
+        self.widget.blockSignals(True)
+        try:
+            self.widget.clearSelection()
+        finally:
+            self.widget.blockSignals(False)
 
     def _path_to_item(self, path):
         s = self.shadow
@@ -964,7 +973,11 @@ class TreeView(WidgetBase):
 
     def select_path(self, path, state=True):
         item = self._path_to_item(path)
-        item.setSelected(state)
+        self.widget.blockSignals(True)
+        try:
+            item.setSelected(state)
+        finally:
+            self.widget.blockSignals(False)
 
     def highlight_path(self, path, onoff, font_color='green'):
         item = self._path_to_item(path)
@@ -1017,33 +1030,6 @@ class TreeView(WidgetBase):
         drag_pkg.start_drag()
 
 
-class WebView(WidgetBase):
-    def __init__(self):
-        if not has_webkit:
-            raise NotImplementedError("Missing webkit")
-
-        super(WebView, self).__init__()
-        self.widget = QWebView()
-
-    def load_url(self, url):
-        self.widget.load(QtCore.QUrl(url))
-
-    def load_html_string(self, html_string):
-        self.widget.setHtml(html_string)
-
-    def go_back(self):
-        self.widget.back()
-
-    def go_forward(self):
-        self.widget.forward()
-
-    def reload_page(self):
-        self.widget.reload()
-
-    def stop_loading(self):
-        self.widget.stop()
-
-
 # CONTAINERS
 
 class ContainerBase(WidgetBase):
@@ -1201,10 +1187,10 @@ class Expander(ContainerBase):
         # these icons in the class variable declarations
         if Expander.r_arrow is None:
             Expander.r_arrow = QtHelp.get_icon(
-                os.path.join(icondir, 'triangle-right-48.png'), size=(12, 12))
+                os.path.join(icondir, 'triangle-right.svg'), size=(12, 12))
         if Expander.d_arrow is None:
             Expander.d_arrow = QtHelp.get_icon(
-                os.path.join(icondir, 'triangle-down-48.png'), size=(12, 12))
+                os.path.join(icondir, 'triangle-down.svg'), size=(12, 12))
 
         self.widget = QtGui.QWidget()
         vbox = QtGui.QVBoxLayout()
@@ -1733,21 +1719,17 @@ class Toolbar(ContainerBase):
         self._menu = None
         self.widget.setStyleSheet(
             """
-            QToolBar { padding: 0; spacing: 0; }\n
-            QToolBar QToolButton { padding: 0; margin: 0; }\n
+            QToolBar { padding: 0; spacing: 1; }\n
+            QToolBar QToolButton { padding: 2; margin: 0; }\n
             """)
 
     def add_action(self, text, toggle=False, iconpath=None, iconsize=None):
         child = ToolbarAction()
         if iconpath:
-            image = QImage(iconpath)
             wd, ht = 24, 24
             if iconsize is not None:
                 wd, ht = iconsize
-            qsize = QtCore.QSize(wd, ht)
-            image = image.scaled(qsize)
-            pixmap = QPixmap.fromImage(image)
-            iconw = QIcon(pixmap)
+            iconw = QtHelp.get_icon(iconpath, size=(wd, ht))
             action = self.widget.addAction(iconw, text,
                                            child._cb_redirect)
             if text is not None and len(text) > 0:
@@ -1847,11 +1829,18 @@ class Menu(ContainerBase):
         if widget is not None:
             w = widget.get_widget()
             if w.isEnabled():
-                # self.widget.popup(w.mapToGlobal(QtCore.QPoint(0, 0)))
-                self.widget.exec(w.mapToGlobal(QtCore.QPoint(0, 0)))
+                if hasattr(self.widget, 'exec_'):
+                    # PySide2
+                    self.widget.exec_(w.mapToGlobal(QtCore.QPoint(0, 0)))
+                else:
+                    self.widget.exec(w.mapToGlobal(QtCore.QPoint(0, 0)))
         else:
             if self.widget.isEnabled():
-                self.widget.exec(QCursor.pos())
+                if hasattr(self.widget, 'exec_'):
+                    # PySide2
+                    self.widget.exec_(QCursor.pos())
+                else:
+                    self.widget.exec(QCursor.pos())
 
     def get_menu(self, name):
         return self.menus[name]
@@ -1863,7 +1852,7 @@ class Menubar(ContainerBase):
 
         self.widget = QtGui.QMenuBar()
         if hasattr(self.widget, 'setNativeMenuBar'):
-            self.widget.setNativeMenuBar(False)
+            self.widget.setNativeMenuBar(True)
         self.menus = Bunch.Bunch(caseless=True)
 
     def add_widget(self, child, name):
@@ -2109,7 +2098,7 @@ class Application(Callback.Callbacks):
         ydpi = screen.physicalDotsPerInchY()
         self.screen_res = max(xdpi, ydpi)
 
-        for name in ('shutdown', ):
+        for name in ('close', 'shutdown'):
             self.enable_callback(name)
 
     def get_screen_size(self):
@@ -2151,7 +2140,20 @@ class Application(Callback.Callbacks):
     def mainloop(self):
         self._qtapp.exec()
 
+    def close(self):
+        """Called when someone is asking the application to close.
+        Can register for this callback if you want an application-wide
+        event to confirm closure.
+        """
+        self.make_callback('close')
+
     def quit(self):
+        """Called when someone is forcibly quitting the application.
+        Can register for this callback if you want an application-wide
+        event to clean up before shutdown.
+        """
+        self.make_callback('shutdown')
+
         self._qtapp.quit()
 
 
@@ -2165,6 +2167,7 @@ class Dialog(TopLevelMixin, WidgetBase):
             parent = parent.get_widget()
         self.widget = QtGui.QDialog(parent)
         self.widget.setModal(modal)
+        self.buttons = []
 
         vbox = QtGui.QVBoxLayout()
         vbox.setContentsMargins(0, 0, 0, 0)
@@ -2178,16 +2181,19 @@ class Dialog(TopLevelMixin, WidgetBase):
         if len(buttons) > 0:
             hbox_w = QtGui.QWidget()
             hbox = QtGui.QHBoxLayout()
+            hbox.setContentsMargins(5, 5, 5, 5)
+            hbox.setSpacing(4)
             hbox_w.setLayout(hbox)
 
             for name, val in buttons:
-                btn = QtGui.QPushButton(name)
+                btn = Button(name)
+                self.buttons.append(btn)
 
                 def cb(val):
-                    return lambda: self._cb_redirect(val)
+                    return lambda w: self._cb_redirect(val)
 
-                btn.clicked.connect(cb(val))
-                hbox.addWidget(btn, stretch=0)
+                btn.add_callback('activated', cb(val))
+                hbox.addWidget(btn.get_widget(), stretch=1)
 
             vbox.addWidget(hbox_w, stretch=0)
             # self.widget.closeEvent = lambda event: self.delete()
@@ -2280,15 +2286,15 @@ def make_widget(title, wtype):
     elif wtype == 'llabel':
         w = Label(title)
         w.widget.setAlignment(QtCore.Qt.AlignLeft)
-    elif wtype == 'entry':
+    elif wtype in ('textentry', 'entry'):
         w = TextEntry()
         # w.widget.setMaxLength(12)
-    elif wtype == 'entryset':
+    elif wtype in ('textentryset', 'entryset'):
         w = TextEntrySet()
         # w.widget.setMaxLength(12)
     elif wtype == 'combobox':
         w = ComboBox()
-    elif wtype == 'spinbutton':
+    elif wtype in ('spinbox', 'spinbutton'):
         w = SpinBox(dtype=int)
     elif wtype == 'spinfloat':
         w = SpinBox(dtype=float)
