@@ -13,14 +13,16 @@ import os
 import logging
 import logging.handlers
 import threading
-import traceback
+
+# 3rd party
+import yaml
 
 # Local application imports
 from ginga.misc.Bunch import Bunch
 from ginga.misc import Task, ModuleManager, Settings, log
 import ginga.version as version
 import ginga.toolkit as ginga_toolkit
-from ginga.util import paths, rgb_cms, json, compat
+from ginga.util import paths, rgb_cms, compat, loader
 
 # Catch warnings
 logging.captureWarnings(True)
@@ -73,102 +75,130 @@ plugins = [
     # hidden plugins, started at program initialization
     Bunch(module='Operations', workspace='operations', start=True,
           hidden=True, category='System', menu="Operations [G]",
-          ptype='global'),
+          ptype='global', enabled=True),
     Bunch(module='Toolbar', workspace='toolbar', start=True,
-          hidden=True, category='System', menu="Toolbar [G]", ptype='global'),
+          hidden=True, category='System', menu="Toolbar [G]", ptype='global',
+          enabled=True),
     Bunch(module='Pan', workspace='uleft', start=True,
-          hidden=True, category='System', menu="Pan [G]", ptype='global'),
+          hidden=True, category='System', menu="Pan [G]", ptype='global',
+          enabled=True),
     Bunch(module='Info', tab='Synopsis', workspace='lleft', start=True,
-          hidden=True, category='System', menu="Info [G]", ptype='global'),
+          hidden=True, category='System', menu="Info [G]", ptype='global',
+          enabled=True),
     Bunch(module='Thumbs', tab='Thumbs', workspace='right', start=True,
-          hidden=True, category='System', menu="Thumbs [G]", ptype='global'),
+          hidden=True, category='System', menu="Thumbs [G]", ptype='global',
+          enabled=True),
     Bunch(module='Contents', tab='Contents', workspace='right', start=True,
-          hidden=True, category='System', menu="Contents [G]", ptype='global'),
+          hidden=True, category='System', menu="Contents [G]", ptype='global',
+          enabled=True),
     Bunch(module='Colorbar', workspace='cbar', start=True,
-          hidden=True, category='System', menu="Colorbar [G]", ptype='global'),
+          hidden=True, category='System', menu="Colorbar [G]", ptype='global',
+          enabled=True),
     Bunch(module='Cursor', workspace='readout', start=True,
-          hidden=True, category='System', menu="Cursor [G]", ptype='global'),
+          hidden=True, category='System', menu="Cursor [G]", ptype='global',
+          enabled=True),
     Bunch(module='Errors', tab='Errors', workspace='right', start=True,
-          hidden=True, category='System', menu="Errors [G]", ptype='global'),
+          hidden=True, category='System', menu="Errors [G]", ptype='global',
+          enabled=True),
     Bunch(module='Downloads', tab='Downloads', workspace='right', start=False,
-          menu="Downloads [G]", category='Utils', ptype='global'),
+          menu="Downloads [G]", category='Utils', ptype='global', enabled=True),
 
     # optional, user-started plugins
     Bunch(module='Blink', tab='Blink Channels', workspace='right', start=False,
-          menu="Blink Channels [G]", category='Analysis', ptype='global'),
+          name='Blink[channels]', menu="Blink Channels [G]",
+          category='Analysis', ptype='global', enabled=True),
     Bunch(module='Blink', workspace='dialogs', menu='Blink Images',
-          category='Analysis', ptype='local'),
+          name='Blink[images]', category='Analysis', ptype='local',
+          enabled=True),
     Bunch(module='Crosshair', workspace='left', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='Cuts', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='LineProfile', workspace='dialogs',
-          category='Analysis.Datacube', ptype='local'),
+          category='Analysis.Datacube', ptype='local', enabled=True),
     Bunch(module='Histogram', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='Overlays', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='Pick', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='PixTable', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='TVMark', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='TVMask', workspace='dialogs', category='Analysis',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='WCSMatch', tab='WCSMatch', workspace='right', start=False,
-          menu="WCS Match [G]", category='Analysis', ptype='global'),
+          menu="WCS Match [G]", category='Analysis', ptype='global',
+          enabled=True),
     Bunch(module='Command', tab='Command', workspace='lleft', start=False,
-          menu="Command Line [G]", category='Debug', ptype='global'),
+          menu="Command Line [G]", category='Debug', ptype='global',
+          enabled=True),
     Bunch(module='Log', tab='Log', workspace='right', start=False,
-          menu="Logger Info [G]", category='Debug', ptype='global'),
+          menu="Logger Info [G]", category='Debug', ptype='global',
+          enabled=True),
     Bunch(module='MultiDim', workspace='lleft', category='Navigation',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='RC', tab='RC', workspace='right', start=False,
-          menu="Remote Control [G]", category='Remote', ptype='global'),
+          menu="Remote Control [G]", category='Remote', ptype='global',
+          enabled=True),
     Bunch(module='SAMP', tab='SAMP', workspace='right', start=False,
-          menu="SAMP Client [G]", category='Remote', ptype='global'),
-    Bunch(module='Compose', workspace='dialogs', category='RGB', ptype='local'),
+          menu="SAMP Client [G]", category='Remote', ptype='global',
+          enabled=False),
+    Bunch(module='Compose', workspace='dialogs', category='RGB', ptype='local',
+          enabled=False),
     Bunch(module='ScreenShot', workspace='dialogs', category='RGB',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='ColorMapPicker', tab='ColorMapPicker',
-          menu="Set Color Map [G]", workspace='right', start=False,
-          category='RGB', ptype='global'),
+          name="ColorMapPicker[G]", menu="Set Color Map [G]",
+          workspace='right', start=False,
+          category='RGB', ptype='global', enabled=True),
     Bunch(module='ColorMapPicker',
           menu="Set Color Map", workspace='dialogs', category='RGB',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='PlotTable', workspace='dialogs', category='Table',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='Catalogs', workspace='dialogs', category='Utils',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='Drawing', workspace='dialogs', category='Utils',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='AutoLoad', workspace='dialogs', category='Utils',
-          ptype='local'),
-    #Bunch(module='Pipeline', workspace='dialogs', category='Utils',
-    #      ptype='local'),
+          ptype='local', enabled=False),
+    Bunch(module='Pipeline', workspace='dialogs', category='Utils',
+          ptype='local', enabled=False),
     Bunch(module='FBrowser', workspace='dialogs', category='Utils',
-          ptype='local'),
+          ptype='local', enabled=True),
     Bunch(module='ChangeHistory', tab='History', workspace='right',
-          menu="History [G]", start=False, category='Utils', ptype='global'),
-    Bunch(module='Mosaic', workspace='dialogs', category='Utils', ptype='local'),
-    Bunch(module='Collage', workspace='dialogs', category='Utils', ptype='local'),
+          menu="History [G]", start=False, category='Utils', ptype='global',
+          enabled=True),
+    Bunch(module='Mosaic', workspace='dialogs', category='Utils', ptype='local',
+          enabled=True),
+    Bunch(module='Collage', workspace='dialogs', category='Utils', ptype='local',
+          enabled=True),
     Bunch(module='FBrowser', tab='Open File', workspace='right',
-          menu="Open File [G]", start=False, category='Utils', ptype='global'),
+          name="FBrowser[G]", menu="Open File [G]", start=False,
+          category='Utils', ptype='global', enabled=True),
     Bunch(module='Preferences', workspace='dialogs', category='Utils',
-          ptype='local'),
-    Bunch(module='Ruler', workspace='dialogs', category='Utils', ptype='local'),
+          ptype='local', enabled=True),
+    Bunch(module='Ruler', workspace='dialogs', category='Utils', ptype='local',
+          enabled=True),
     # TODO: Add SaveImage to File menu.
     Bunch(module='SaveImage', tab='SaveImage', workspace='right',
-          menu="Save File [G]", start=False, category='Utils', ptype='global'),
+          menu="Save File [G]", start=False, category='Utils', ptype='global',
+          enabled=True),
     Bunch(module='WCSAxes', workspace='dialogs', category='Utils',
-          ptype='local'),
-    Bunch(module='WBrowser', tab='Help', workspace='channels', start=False,
-          menu="Help [G]", category='Help', ptype='global'),
+          ptype='local', enabled=True),
     Bunch(module='Header', tab='Header', workspace='left', start=False,
-          menu="Header [G]", hidden=False, category='Utils', ptype='global'),
+          menu="Header [G]", hidden=False, category='Utils', ptype='global',
+          enabled=True),
     Bunch(module='Zoom', tab='Zoom', workspace='left', start=False,
-          menu="Zoom [G]", category='Utils', ptype='global'),
+          menu="Zoom [G]", category='Utils', ptype='global', enabled=True),
+    Bunch(module='LoaderConfig', tab='Loaders', workspace='channels',
+          start=False, menu="LoaderConfig [G]", category='Debug',
+          ptype='global', enabled=True),
+    Bunch(module='PluginConfig', tab='Plugins', workspace='channels',
+          start=False, menu="PluginConfig [G]", category='Debug',
+          ptype='global', enabled=True),
 ]
 
 
@@ -177,17 +207,36 @@ class ReferenceViewer(object):
     This class exists solely to be able to customize the reference
     viewer startup.
     """
-    def __init__(self, layout=default_layout, plugins=plugins):
+    def __init__(self, layout=default_layout, plugins=plugins, appname='ginga',
+                 basedir=None, channels=None):
+        self.appname = appname
+        self.basedir = basedir
         self.layout = layout
-        self.channels = ['Image']
+        if channels is None:
+            channels = ['Image']
+        self.channels = channels
         self.default_plugins = plugins
         self.plugins = []
+        self.plugin_dct = dict()
 
     def add_plugin_spec(self, spec):
         self.plugins.append(spec)
+        plugin_name = self.get_plugin_name(spec)
+        self.plugin_dct[plugin_name] = spec
 
     def clear_default_plugins(self):
         self.plugins = []
+        self.plugin_dct = dict()
+
+    def get_plugin_name(self, spec):
+        if 'name' in spec:
+            return spec['name']
+        module = spec['module']
+        if '.' in module:
+            module = module.split('.')[-1]
+        klass = spec.get('klass', None)
+        name = module if klass is None else klass
+        return name
 
     def add_default_plugins(self, except_global=[], except_local=[]):
         """
@@ -204,7 +253,8 @@ class ReferenceViewer(object):
                 self.add_plugin_spec(spec)
 
     def add_separately_distributed_plugins(self):
-        groups = ['ginga.rv.plugins']
+        groups = ['ginga.rv.plugins', 'ginga_plugins',
+                  '{}_plugins'.format(self.appname)]
         available_methods = []
 
         for group in groups:
@@ -246,9 +296,6 @@ class ReferenceViewer(object):
                      help="Buffer length to NUM")
         add_argument('-c', "--channels", dest="channels",
                      help="Specify list of channels to create")
-        add_argument("--debug", dest="debug", default=False,
-                     action="store_true",
-                     help="Enter the pdb debugger on main()")
         add_argument("--disable-plugins", dest="disable_plugins",
                      metavar="NAMES",
                      help="Specify plugins that should be disabled")
@@ -269,16 +316,13 @@ class ReferenceViewer(object):
                      action="store_true",
                      help="Don't display the splash screen")
         add_argument("--numthreads", dest="numthreads", type=int,
-                     default=30, metavar="NUM",
+                     default=None, metavar="NUM",
                      help="Start NUM threads in thread pool")
         add_argument("--opengl", dest="opengl", default=False,
                      action="store_true",
                      help="Use OpenGL acceleration")
         add_argument("--plugins", dest="plugins", metavar="NAMES",
                      help="Specify additional plugins to load")
-        add_argument("--profile", dest="profile", action="store_true",
-                     default=False,
-                     help="Run the profiler on main()")
         add_argument("--sep", dest="separate_channels", default=False,
                      action="store_true",
                      help="Load files in separate channels")
@@ -305,38 +349,44 @@ class ReferenceViewer(object):
         `args` is a list of arguments to the viewer after parsing out
         options.  It should contain a list of files or URLs to load.
         """
+        logname = self.appname.lower().replace(' ', '_')
 
         # Create a logger
-        logger = log.get_logger(name='ginga', options=options)
+        logger = log.get_logger(name=logname, options=options)
 
         if options.basedir is not None:
-            paths.ginga_home = os.path.expanduser(options.basedir)
+            self.basedir = os.path.expanduser(options.basedir)
+        if self.basedir is not None:
+            paths.ginga_home = self.basedir
+        else:
+            self.basedir = paths.ginga_home
 
         # Get settings (preferences)
-        basedir = paths.ginga_home
-        if not os.path.exists(basedir):
+        if not os.path.exists(self.basedir):
             try:
-                os.mkdir(basedir)
+                os.mkdir(self.basedir)
             except OSError as e:
                 logger.warning(
-                    "Couldn't create ginga settings area (%s): %s" % (
-                        basedir, str(e)))
+                    "Couldn't create %s settings area (%s): %s" % (
+                        self.appname, self.basedir, str(e)))
                 logger.warning("Preferences will not be able to be saved")
 
         # Set up preferences
-        prefs = Settings.Preferences(basefolder=basedir, logger=logger)
+        prefs = Settings.Preferences(basefolder=self.basedir, logger=logger)
         settings = prefs.create_category('general')
-        settings.set_defaults(useMatplotlibColormaps=False,
+        settings.set_defaults(title=self.appname.capitalize(),
+                              useMatplotlibColormaps=False,
                               widgetSet='choose',
                               WCSpkg='choose', FITSpkg='choose',
                               suppress_fits_warnings=False,
                               recursion_limit=2000,
+                              num_threads=30,
                               icc_working_profile=None,
                               font_scaling_factor=None,
                               save_layout=True,
                               use_opengl=False,
-                              layout_file='layout',
-                              plugin_file='plugins.json',
+                              layout_file='layout.json',
+                              plugin_file='plugins.yml',
                               channel_prefix="Image")
         settings.load(onError='silent')
 
@@ -344,35 +394,32 @@ class ReferenceViewer(object):
         sys.setrecursionlimit(settings.get('recursion_limit'))
 
         # So we can find our plugins
-        sys.path.insert(0, basedir)
+        sys.path.insert(0, self.basedir)
         package_home = os.path.split(sys.modules['ginga.version'].__file__)[0]
         child_dir = os.path.join(package_home, 'rv', 'plugins')
         sys.path.insert(0, child_dir)
-        plugin_dir = os.path.join(basedir, 'plugins')
+        plugin_dir = os.path.join(self.basedir, 'plugins')
         sys.path.insert(0, plugin_dir)
 
-        gc = os.path.join(basedir, "ginga_config.py")
-        have_ginga_config = os.path.exists(gc)
+        # Create the dynamic module manager
+        mm = ModuleManager.ModuleManager(logger)
+
+        # what is the dynamic config file to load
+        app_config = "{}_config".format(self.appname)
+        gc = os.path.join(self.basedir, f"{app_config}.py")
+        have_app_config = os.path.exists(gc)
 
         # User configuration, earliest possible intervention
-        if have_ginga_config:
+        if have_app_config:
             try:
-                import ginga_config
+                app_config = mm.load_module(app_config)
 
-                if hasattr(ginga_config, 'init_config'):
-                    ginga_config.init_config(self)
+                if hasattr(app_config, 'init_config'):
+                    app_config.init_config(self)
 
             except Exception as e:
-                try:
-                    (type, value, tb) = sys.exc_info()
-                    tb_str = "\n".join(traceback.format_tb(tb))
-
-                except Exception:
-                    tb_str = "Traceback information unavailable."
-
-                logger.error("Error processing Ginga config file: %s" % (
-                    str(e)))
-                logger.error("Traceback:\n%s" % (tb_str))
+                logger.error("Error processing %s config file: %s" % (
+                    self.appname, str(e)), exc_info=True)
 
         # Choose a toolkit
         if options.toolkit:
@@ -441,24 +488,19 @@ class ReferenceViewer(object):
 
         try:
             from ginga.util.io import io_fits
-            from ginga.util import loader
             if fitspkg != 'choose':
                 assert io_fits.use(fitspkg) is True
-                # opener name is not necessarily the same
-                opener = loader.get_opener(io_fits.fitsLoaderClass.name)
-                # set this opener as the priority one
-                opener.priority = -99
 
         except Exception as e:
             logger.warning(
                 "failed to set FITS package preference '{}': {}".format(fitspkg, e))
 
-        # Create the dynamic module manager
-        mm = ModuleManager.ModuleManager(logger)
-
-        # Create and start thread pool
         ev_quit = threading.Event()
-        thread_pool = Task.ThreadPool(options.numthreads, logger,
+        # Create and start thread pool
+        num_threads = settings.get('num_threads', 30)
+        if options.numthreads is not None:
+            num_threads = options.numthreads
+        thread_pool = Task.ThreadPool(num_threads, logger,
                                       ev_quit=ev_quit)
         thread_pool.startall()
 
@@ -469,45 +511,23 @@ class ReferenceViewer(object):
         if options.opengl:
             settings.set(use_opengl=True)
 
-        layout_file = os.path.join(basedir, settings.get('layout_file',
-                                                         'layout'))
+        layout_file = os.path.join(self.basedir, settings.get('layout_file',
+                                                              'layout.json'))
         ginga_shell.set_layout(self.layout, layout_file=layout_file,
                                save_layout=settings.get('save_layout', True))
 
         # User configuration (custom star catalogs, etc.)
-        if have_ginga_config:
+        if have_app_config:
             try:
-                if hasattr(ginga_config, 'pre_gui_config'):
-                    ginga_config.pre_gui_config(ginga_shell)
+                if hasattr(app_config, 'pre_gui_config'):
+                    app_config.pre_gui_config(ginga_shell)
             except Exception as e:
-                try:
-                    (type, value, tb) = sys.exc_info()
-                    tb_str = "\n".join(traceback.format_tb(tb))
-
-                except Exception:
-                    tb_str = "Traceback information unavailable."
-
-                logger.error("Error importing Ginga config file: %s" % (
-                    str(e)))
-                logger.error("Traceback:\n%s" % (tb_str))
+                logger.error("Error importing %s config file: %s" % (
+                    self.appname, str(e)), exc_info=True)
 
         # Build desired layout
         ginga_shell.build_toplevel(ignore_saved_layout=options.norestore)
 
-        # Does user have a customized plugin setup?  If so, override the
-        # default plugins to be that
-        plugin_file = settings.get('plugin_file', None)
-        if plugin_file is not None:
-            plugin_file = os.path.join(basedir, plugin_file)
-            if os.path.exists(plugin_file):
-                logger.info("Reading plugin file '%s'..." % (plugin_file))
-                try:
-                    with open(plugin_file, 'r') as in_f:
-                        buf = in_f.read()
-                        self.plugins = json.loads(buf)
-                except Exception as e:
-                    logger.error("Error reading plugin file: %s" % (str(e)))
-
         # Did user specify a particular geometry?
         if options.geometry:
             ginga_shell.set_geometry(options.geometry)
@@ -519,6 +539,7 @@ class ReferenceViewer(object):
             disabled_plugins = settings.get('disable_plugins', [])
             if not isinstance(disabled_plugins, list):
                 disabled_plugins = disabled_plugins.lower().split(',')
+        disabled_plugins = set(disabled_plugins)
 
         # Add GUI log handler (for "Log" global plugin)
         guiHdlr = GuiLogHandler(ginga_shell)
@@ -527,15 +548,72 @@ class ReferenceViewer(object):
         guiHdlr.setFormatter(fmt)
         logger.addHandler(guiHdlr)
 
-        # Load any custom modules
+        # Set loader priorities, if user has saved any
+        # (see LoaderConfig plugin)
+        path = os.path.join(self.basedir, 'loaders.yml')
+        if os.path.exists(path):
+            try:
+                with open(path, 'r') as in_f:
+                    loader_dct = yaml.safe_load(in_f.read())
+
+                # set saved priorities for openers
+                for mimetype, m_dct in loader_dct.items():
+                    for name, l_dct in m_dct.items():
+                        opener = loader.get_opener(name)
+                        loader.add_opener(opener, [mimetype],
+                                          priority=l_dct['priority'],
+                                          note=opener.__doc__)
+
+            except Exception as e:
+                logger.error(f"failed to process loader file '{path}': {e}",
+                             exc_info=True)
+
+        # Does user have a saved plugin setup?  If so, check which
+        # plugins should be disabled, or have a customized category or
+        # workspace
+        plugin_file = settings.get('plugin_file', None)
+        if plugin_file is not None:
+            plugin_file = os.path.join(self.basedir, plugin_file)
+            if os.path.exists(plugin_file):
+                logger.info("Reading plugin file '%s'..." % (plugin_file))
+                try:
+                    with open(plugin_file, 'r') as in_f:
+                        buf = in_f.read()
+                        _plugins = yaml.safe_load(buf)
+
+                    for dct in _plugins:
+                        plugin_name = self.get_plugin_name(dct)
+                        if plugin_name in self.plugin_dct:
+                            # we know about this plugin, override listed
+                            # attributes
+                            spec = self.plugin_dct[plugin_name]
+                            for name in ['enabled', 'category', 'hidden',
+                                         'workspace', 'tab', 'menu',
+                                         'pfx', 'optray']:
+                                if name in dct:
+                                    spec[name] = dct[name]
+                            if spec['ptype'] == 'global':
+                                spec['start'] = dct.get('start',
+                                                        spec.get('start', False))
+                        else:
+                            # unknown plugin
+                            spec = Bunch(dct)
+                            self.add_plugin_spec(spec)
+
+                except Exception as e:
+                    logger.error(f"Error reading plugin file: {e}",
+                                 exc_info=True)
+
+        # Load any custom global plugins named on command line or in
+        # general.cfg
         if options.modules is not None:
-            modules = options.modules.split(',')
+            global_plugins = options.modules.split(',')
         else:
-            modules = settings.get('global_plugins', [])
-            if not isinstance(modules, list):
-                modules = modules.split(',')
+            global_plugins = settings.get('global_plugins', [])
+            if not isinstance(global_plugins, list):
+                global_plugins = global_plugins.split(',')
 
-        for long_plugin_name in modules:
+        for long_plugin_name in global_plugins:
             if '.' in long_plugin_name:
                 tmpstr = long_plugin_name.split('.')
                 plugin_name = tmpstr[-1]
@@ -543,22 +621,28 @@ class ReferenceViewer(object):
             else:
                 plugin_name = long_plugin_name
                 pfx = None
-            menu_name = "%s [G]" % (plugin_name)
-            spec = Bunch(name=plugin_name, module=plugin_name,
-                         ptype='global', tab=plugin_name,
-                         menu=menu_name, category="Custom",
-                         workspace='right', pfx=pfx)
-            self.add_plugin_spec(spec)
+            if plugin_name in self.plugin_dct:
+                spec = self.plugin_dct[plugin_name]
+                spec.enabled = True
+            else:
+                menu_name = f"{plugin_name} [G]"
+                spec = Bunch(name=plugin_name, module=plugin_name,
+                             ptype='global', tab=plugin_name,
+                             menu=menu_name, category="Custom",
+                             enabled=True,
+                             workspace='right', pfx=pfx)
+                self.add_plugin_spec(spec)
 
-        # Load any custom local plugins
+        # Load any custom local plugins named on command line or in
+        # general.cfg
         if options.plugins is not None:
-            plugins = options.plugins.split(',')
+            local_plugins = options.plugins.split(',')
         else:
-            plugins = settings.get('local_plugins', [])
-            if not isinstance(plugins, list):
-                plugins = plugins.split(',')
+            local_plugins = settings.get('local_plugins', [])
+            if not isinstance(local_plugins, list):
+                local_plugins = local_plugins.split(',')
 
-        for long_plugin_name in plugins:
+        for long_plugin_name in local_plugins:
             if '.' in long_plugin_name:
                 tmpstr = long_plugin_name.split('.')
                 plugin_name = tmpstr[-1]
@@ -566,16 +650,20 @@ class ReferenceViewer(object):
             else:
                 plugin_name = long_plugin_name
                 pfx = None
-            spec = Bunch(module=plugin_name, workspace='dialogs',
-                         ptype='local', category="Custom",
-                         hidden=False, pfx=pfx)
-            self.add_plugin_spec(spec)
+            if plugin_name in self.plugin_dct:
+                spec = self.plugin_dct[plugin_name]
+                spec.enabled = True
+            else:
+                spec = Bunch(module=plugin_name, workspace='dialogs',
+                             ptype='local', category="Custom",
+                             hidden=False, pfx=pfx, enabled=True)
+                self.add_plugin_spec(spec)
 
-        # Mark disabled plugins
+        # Mark disabled plugins (command-line has precedence)
         for spec in self.plugins:
-            if spec.get('enabled', None) is None:
-                spec['enabled'] = (False if spec.module.lower() in disabled_plugins
-                                   else True)
+            if spec.module.lower() in disabled_plugins:
+                spec['enabled'] = False
+
         # submit plugin specs to shell
         ginga_shell.set_plugins(self.plugins)
 
@@ -601,44 +689,33 @@ class ReferenceViewer(object):
             if not isinstance(channels, list):
                 channels = channels.split(',')
 
-        if len(channels) == 0:
-            # should provide at least one default channel?
-            channels = [settings.get('channel_prefix', "Image")]
+        if len(channels) > 0:
+            # populate the initial channel lineup
+            for item in channels:
+                if isinstance(item, str):
+                    chname, wsname = item, None
+                else:
+                    chname, wsname = item
+                ginga_shell.add_channel(chname, workspace=wsname)
 
-        # populate the initial channel lineup
-        for item in channels:
-            if isinstance(item, str):
-                chname, wsname = item, None
-            else:
-                chname, wsname = item
-            ginga_shell.add_channel(chname, workspace=wsname)
-
-        ginga_shell.change_channel(chname)
+            ginga_shell.change_channel(chname)
 
         # User configuration (custom star catalogs, etc.)
-        if have_ginga_config:
+        if have_app_config:
             try:
-                if hasattr(ginga_config, 'post_gui_config'):
-                    ginga_config.post_gui_config(ginga_shell)
+                if hasattr(app_config, 'post_gui_config'):
+                    app_config.post_gui_config(ginga_shell)
 
             except Exception as e:
-                try:
-                    (type, value, tb) = sys.exc_info()
-                    tb_str = "\n".join(traceback.format_tb(tb))
-
-                except Exception:
-                    tb_str = "Traceback information unavailable."
-
-                logger.error("Error processing Ginga config file: %s" % (
-                    str(e)))
-                logger.error("Traceback:\n%s" % (tb_str))
+                logger.error("Error processing %s config file: %s" % (
+                    self.appname, str(e)), exc_info=True)
 
         # Redirect warnings to logger
         for hdlr in logger.handlers:
             logging.getLogger('py.warnings').addHandler(hdlr)
 
         # Display banner the first time run, unless suppressed
-        show_banner = True
+        show_banner = (self.appname == 'ginga')
         try:
             show_banner = settings.get('showBanner')
 
@@ -666,23 +743,24 @@ class ReferenceViewer(object):
             else:
                 expanded_args.append(imgfile)
 
-        # Assume remaining arguments are fits files and load them.
-        if not options.separate_channels:
-            chname = channels[0]
-            ginga_shell.gui_do(ginga_shell.open_uris, expanded_args,
-                               chname=chname)
-        else:
-            i = 0
-            num_channels = len(channels)
-            for imgfile in expanded_args:
-                if i < num_channels:
-                    chname = channels[i]
-                    i = i + 1
-                else:
-                    channel = ginga_shell.add_channel_auto()
-                    chname = channel.name
-                ginga_shell.gui_do(ginga_shell.open_uris, [imgfile],
+        if len(channels) > 0:
+            # Assume remaining arguments are fits files and load them.
+            if not options.separate_channels:
+                chname = channels[0]
+                ginga_shell.gui_do(ginga_shell.open_uris, expanded_args,
                                    chname=chname)
+            else:
+                i = 0
+                num_channels = len(channels)
+                for imgfile in expanded_args:
+                    if i < num_channels:
+                        chname = channels[i]
+                        i = i + 1
+                    else:
+                        channel = ginga_shell.add_channel_auto()
+                        chname = channel.name
+                    ginga_shell.gui_do(ginga_shell.open_uris, [imgfile],
+                                       chname=chname)
 
         try:
             try:
@@ -707,7 +785,8 @@ class ReferenceViewer(object):
 
 def reference_viewer(sys_argv):
     """Create reference viewer from command line."""
-    viewer = ReferenceViewer(layout=default_layout)
+    viewer = ReferenceViewer(layout=default_layout, plugins=plugins,
+                             appname='ginga', basedir=None, channels=['Image'])
     viewer.add_default_plugins()
     viewer.add_separately_distributed_plugins()
 
@@ -723,22 +802,7 @@ def reference_viewer(sys_argv):
     if options.display:
         os.environ['DISPLAY'] = options.display
 
-    # Are we debugging this?
-    if options.debug:
-        import pdb
-
-        pdb.run('viewer.main(options, args)')
-
-    # Are we profiling this?
-    elif options.profile:
-        import profile
-
-        print(("%s profile:" % sys_argv[0]))
-        profile.runctx('viewer.main(options, args)',
-                       dict(options=options, args=args, viewer=viewer), {})
-
-    else:
-        viewer.main(options, args)
+    viewer.main(options, args)
 
 
 def _main():
