@@ -38,7 +38,7 @@ the other tiles.
 """
 import math
 import time
-from datetime import datetime
+from datetime import datetime, timezone
 import threading
 
 import numpy as np
@@ -355,7 +355,7 @@ class Mosaic(GingaPlugin.LocalPlugin):
                                    suppress_callback=True)
 
         # Add description for ChangeHistory
-        info = dict(time_modified=datetime.utcnow(),
+        info = dict(time_modified=datetime.now(tz=timezone.utc),
                     reason_modified='Added {0}'.format(
             ','.join([im.get('name') for im in images])))
         self.fv.update_image_info(self.img_mosaic, info)
