@@ -82,7 +82,7 @@ class MultiDim(GingaPlugin.LocalPlugin):
         self.play_idx = 0
         self.play_max = 0
         self.play_int_sec = 0.1
-        self.play_min_sec = 1.0 / 30
+        self.play_min_sec = 0.0
         self.play_last_time = 0.0
         self.play_fps = 0
         self.timer = fv.get_timer()
@@ -143,7 +143,7 @@ class MultiDim(GingaPlugin.LocalPlugin):
                 ('forward', 'next', lambda w: self.next_slice()),
                 ('play', 'play', lambda w: self.play_start()),
                 ('stop', 'stop', lambda w: self.play_stop()), ):
-            iconpath = os.path.join(self.fv.iconpath, "%s_48.png" % name)
+            iconpath = os.path.join(self.fv.iconpath, "%s.svg" % name)
             btn = tbar.add_action(None, iconpath=iconpath)
             self.w[actn] = btn
             btn.set_enabled(False)
@@ -624,9 +624,13 @@ class MultiDim(GingaPlugin.LocalPlugin):
             hdu_dct = self.file_obj.get_directory()
 
             upper = len(self.file_obj) - 1
-            # NOTE: make a set of values, because some values will be in
-            # multiple times if known by several indexes
-            self.prep_hdu_menu(self.w.hdu, list(set(hdu_dct.values())))
+            # NOTE: make a unique list of values, because some values will
+            # be in multiple times if known by several indexes
+            hdu_lst = []
+            for item in hdu_dct.values():
+                if item not in hdu_lst:
+                    hdu_lst.append(item)
+            self.prep_hdu_menu(self.w.hdu, hdu_lst)
             self.num_hdu = upper
             self.logger.debug("there are %d hdus" % (upper + 1))
             self.w.numhdu.set_text("%d" % (upper + 1))
