@@ -17,7 +17,7 @@ import os.path
 
 from ginga.gw import Widgets
 from ginga.misc import Bunch
-from ginga.Bindings import KeyEvent
+from ginga.events import KeyEvent
 from ginga import GingaPlugin
 
 __all__ = ['Toolbar']
@@ -63,80 +63,83 @@ class Toolbar(GingaPlugin.GlobalPlugin):
         for tup in (
             #("Load", 'button', 'fits_open_48', "Open an image file",
             #None),
-            ("FlipX", 'toggle', 'flipx_48', "Flip image in X axis",
+            ("FlipX", 'toggle', 'flip_x', "Flip image in X axis",
              self.flipx_cb),
-            ("FlipY", 'toggle', 'flipy_48', "Flip image in Y axis",
+            ("FlipY", 'toggle', 'flip_y', "Flip image in Y axis",
              self.flipy_cb),
-            ("SwapXY", 'toggle', 'swapxy_48', "Swap X and Y axes",
+            ("SwapXY", 'toggle', 'swap_xy', "Swap X and Y axes",
              self.swapxy_cb),
             ("---",),
-            ("Rot90", 'button', 'rot90ccw_48', "Rotate image 90 deg",
+            ("Rot90", 'button', 'rot90ccw', "Rotate image 90 deg",
              self.rot90_cb),
-            ("RotN90", 'button', 'rot90cw_48', "Rotate image -90 deg",
+            ("RotN90", 'button', 'rot90cw', "Rotate image -90 deg",
              self.rotn90_cb),
-            ("OrientRH", 'button', 'orient_nw_48', "Orient image N=Up E=Right",
+            ("OrientRH", 'button', 'orient_nw', "Orient image N=Up E=Right",
              self.orient_rh_cb),
-            ("OrientLH", 'button', 'orient_ne_48', "Orient image N=Up E=Left",
+            ("OrientLH", 'button', 'orient_ne', "Orient image N=Up E=Left",
              self.orient_lh_cb),
             ("---",),
-            ## ("Prev", 'button', 'prev_48', "Go to previous channel",
+            ## ("Prev", 'button', 'prev', "Go to previous channel",
             ##  lambda w: self.fv.prev_channel()),
-            ## ("Next", 'button', 'next_48', "Go to next channel",
+            ## ("Next", 'button', 'next', "Go to next channel",
             ##  lambda w: self.fv.next_channel()),
-            ("Up", 'button', 'up_48', "Go to previous image in channel",
+            ("Up", 'button', 'up', "Go to previous image in channel",
              lambda w: self.fv.prev_img()),
-            ("Down", 'button', 'down_48', "Go to next image in channel",
+            ("Down", 'button', 'down', "Go to next image in channel",
              lambda w: self.fv.next_img()),
             ("---",),
-            ("Zoom In", 'button', 'zoom_in_48', "Zoom in",
+            ("Zoom In", 'button', 'zoom_in', "Zoom in",
              lambda w: self.fv.zoom_in()),
-            ("Zoom Out", 'button', 'zoom_out_48', "Zoom out",
+            ("Zoom Out", 'button', 'zoom_out', "Zoom out",
              lambda w: self.fv.zoom_out()),
-            ("Zoom Fit", 'button', 'zoom_fit_48', "Zoom to fit window size",
+            ("Zoom Fit", 'button', 'zoom_fit', "Zoom to fit window size",
              lambda w: self.fv.zoom_fit()),
-            ("Zoom 1:1", 'button', 'zoom_100_48', "Zoom to 100% (1:1)",
+            ("Zoom 1:1", 'button', 'zoom_100', "Zoom to 100% (1:1)",
              lambda w: self.fv.zoom_1_to_1()),
             ("---",),
-            ("Pan", 'toggle', 'pan_48', "Pan with left, zoom with right",
+            ("Pan", 'toggle', 'pan', "Pan with left, zoom with right",
              lambda w, tf: self.mode_cb(tf, 'pan')),
-            ("FreePan", 'toggle', 'hand_48',
+            ("Zoom", 'toggle', 'crosshair',
              "Left/right click zooms in/out;\n"
              "hold middle to pan freely over image",
-             lambda w, tf: self.mode_cb(tf, 'freepan')),
-            ("Rotate", 'toggle', 'rotate_48',
+             lambda w, tf: self.mode_cb(tf, 'zoom')),
+            ("Rotate", 'toggle', 'rotate',
              "Drag left to rotate; click right to reset to 0 deg",
              lambda w, tf: self.mode_cb(tf, 'rotate')),
-            ("Dist", 'toggle', 'distribute_48',
+            ("Dist", 'toggle', 'sqrt',
              "Scroll to set color distribution algorithm",
              lambda w, tf: self.mode_cb(tf, 'dist')),
-            ("Cuts", 'toggle', 'cuts_48',
+            ("CMap", 'toggle', 'palette',
+             "Scroll to set color map",
+             lambda w, tf: self.mode_cb(tf, 'cmap')),
+            ("Cuts", 'toggle', 'cuts',
              "Left/right sets hi cut, up/down sets lo cut",
              lambda w, tf: self.mode_cb(tf, 'cuts')),
-            ("Contrast", 'toggle', 'contrast_48',
+            ("Contrast", 'toggle', 'contrast',
              "Contrast/bias with left/right/up/down",
              lambda w, tf: self.mode_cb(tf, 'contrast')),
-            ("ModeLock", 'toggle', 'lock_48',
+            ("ModeLock", 'toggle', 'lock',
              "Modes are oneshot or locked", self.set_locked_cb),
             ("---",),
-            ("Center", 'button', 'center_image_48', "Center image",
+            ("Center", 'button', 'center_image', "Center image",
              self.center_image_cb),
-            ("Restore", 'button', 'reset_rotation_48',
+            ("Restore", 'button', 'reset_rotation',
              "Reset all transformations and rotations",
              self.reset_all_transforms_cb),
-            ("AutoLevels", 'button', 'auto_cuts_48', "Auto cut levels",
+            ("AutoLevels", 'button', 'auto_cuts', "Auto cut levels",
              self.auto_levels_cb),
-            ("ResetContrast", 'button', 'reset_contrast_48', "Reset contrast",
+            ("ResetContrast", 'button', 'reset_contrast', "Reset contrast",
              self.reset_contrast_cb),
             ("---",),
-            ("Preferences", 'button', 'settings_48', "Set channel preferences",
+            ("Preferences", 'button', 'settings', "Set channel preferences (in focused channel)",
              lambda w: self.start_plugin_cb('Preferences')),
-            ("FBrowser", 'button', 'open_48', "Open file",
+            ("FBrowser", 'button', 'folder_open', "Open file (in focused channel)",
              lambda w: self.start_plugin_cb('FBrowser')),
-            ("MultiDim", 'button', 'layers_48', "Select HDUs or cube slices",
+            ("MultiDim", 'button', 'layers', "Select HDUs or cube slices (in focused channel)",
              lambda w: self.start_plugin_cb('MultiDim')),
-            ("Header", 'button', 'tags_48', "View image metadata",
+            ("Header", 'button', 'tags', "View image metadata (Header plugin)",
              lambda w: self.start_global_plugin_cb('Header')),
-            ("Zoom", 'button', 'microscope_48', "Magnify detail",
+            ("ZoomPlugin", 'button', 'microscope', "Magnify detail (Zoom plugin)",
              lambda w: self.start_global_plugin_cb('Zoom')),
             ):  # noqa
 
@@ -144,9 +147,13 @@ class Toolbar(GingaPlugin.GlobalPlugin):
             if name == '---':
                 tb.add_separator()
                 continue
-            iconpath = os.path.join(self.fv.iconpath, "%s.png" % (tup[2]))
-            btn = tb.add_action(None, toggle=(tup[1] == 'toggle'),
-                                iconpath=iconpath)
+            if tup[1] not in ['button', 'toggle']:
+                btn = Widgets.make_widget(name, tup[1])
+                tb.add_widget(btn)
+            else:
+                iconpath = os.path.join(self.fv.iconpath, "%s.svg" % (tup[2]))
+                btn = tb.add_action(None, toggle=(tup[1] == 'toggle'),
+                                    iconpath=iconpath, iconsize=(24, 24))
             if tup[3]:
                 btn.set_tooltip(tup[3])
             if tup[4]:
@@ -172,11 +179,11 @@ class Toolbar(GingaPlugin.GlobalPlugin):
     # CALLBACKS
 
     def add_channel_cb(self, viewer, channel):
-        fitsimage = channel.fitsimage
-        fitsimage.add_callback('transform', self.viewer_transform_cb)
+        chviewer = channel.fitsimage
+        chviewer.add_callback('transform', self.viewer_transform_cb)
 
-        bm = fitsimage.get_bindmap()
-        bm.add_callback('mode-set', self.mode_set_cb, fitsimage)
+        bm = chviewer.get_bindmap()
+        bm.add_callback('mode-set', self.mode_set_cb, chviewer)
 
     def delete_channel_cb(self, viewer, channel):
         self.logger.debug("delete channel %s" % (channel.name))
@@ -186,9 +193,9 @@ class Toolbar(GingaPlugin.GlobalPlugin):
     def focus_cb(self, viewer, channel):
         self.update_channel_buttons(channel)
 
-        fitsimage = channel.fitsimage
-        self.active = fitsimage
-        self._update_toolbar_state(fitsimage)
+        chviewer = channel.fitsimage
+        self.active = chviewer
+        self._update_toolbar_state(chviewer)
         return True
 
     def center_image_cb(self, w):
@@ -269,41 +276,43 @@ class Toolbar(GingaPlugin.GlobalPlugin):
     def mode_cb(self, tf, modename):
         if self.active is None:
             self.active = self._get_viewer()
-        fitsimage = self.active
-        if fitsimage is None:
+        chviewer = self.active
+        if chviewer is None:
             return
-        bm = fitsimage.get_bindmap()
+        bm = chviewer.get_bindmap()
         if not tf:
-            bm.reset_mode(fitsimage)
+            bm.reset_mode(chviewer)
+            self.fv.show_status("")
             return True
 
         bm.set_mode(modename)
         # just in case mode change failed
-        self._update_toolbar_state(fitsimage)
+        self._update_toolbar_state(chviewer)
+        self.fv.show_status(f"Type 'h' in the viewer to show help for mode {modename}")
         return True
 
-    def mode_set_cb(self, bm, mode, mtype, fitsimage):
+    def mode_set_cb(self, bm, mode, mtype, chviewer):
         # called whenever the user interaction mode is changed
         # in the viewer
         if self.active is None:
             self.active = self._get_viewer()
-        if fitsimage != self.active:
+        if chviewer != self.active:
             return True
-        self._update_toolbar_state(fitsimage)
+        self._update_toolbar_state(chviewer)
         return True
 
-    def viewer_transform_cb(self, fitsimage):
+    def viewer_transform_cb(self, chviewer):
         # called whenever the transform (flip x/y, swap axes) is done
         # in the viewer
         if self.active is None:
             self.active = self._get_viewer()
-        if fitsimage != self.active:
+        if chviewer != self.active:
             return True
-        self._update_toolbar_state(fitsimage)
+        self._update_toolbar_state(chviewer)
         return True
 
-    def new_image_cb(self, fitsimage, image):
-        self._update_toolbar_state(fitsimage)
+    def new_image_cb(self, chviewer, image):
+        self._update_toolbar_state(chviewer)
         return True
 
     def set_locked_cb(self, w, tf):
@@ -313,22 +322,22 @@ class Toolbar(GingaPlugin.GlobalPlugin):
             modetype = 'oneshot'
         if self.active is None:
             self.active = self._get_viewer()
-        fitsimage = self.active
-        if fitsimage is None:
+        chviewer = self.active
+        if chviewer is None:
             return
 
         # get current bindmap, make sure that the mode is consistent
         # with current lock button
-        bm = fitsimage.get_bindmap()
+        bm = chviewer.get_bindmap()
         modename, cur_modetype = bm.current_mode()
         bm.set_default_mode_type(modetype)
 
         bm.set_mode(modename, mode_type=modetype)
         if not tf:
             # turning off lock also resets the mode
-            bm.reset_mode(fitsimage)
+            bm.reset_mode(chviewer)
 
-        self._update_toolbar_state(fitsimage)
+        self._update_toolbar_state(chviewer)
         return True
 
     # LOGIC
@@ -362,29 +371,30 @@ class Toolbar(GingaPlugin.GlobalPlugin):
         self.w.btn_up.set_enabled(enabled)
         self.w.btn_down.set_enabled(enabled)
 
-    def _update_toolbar_state(self, fitsimage):
-        if (fitsimage is None) or (not self.gui_up):
+    def _update_toolbar_state(self, chviewer):
+        if (chviewer is None) or (not self.gui_up):
             return
         self.logger.debug("updating toolbar state")
         try:
             # update transform toggles
-            flipx, flipy, swapxy = fitsimage.get_transforms()
+            flipx, flipy, swapxy = chviewer.get_transforms()
             # toolbar follows view
             self.w.btn_flipx.set_state(flipx)
             self.w.btn_flipy.set_state(flipy)
             self.w.btn_swapxy.set_state(swapxy)
 
             # update mode toggles
-            bm = fitsimage.get_bindmap()
+            bm = chviewer.get_bindmap()
             modename, mode_type = bm.current_mode()
             self.logger.debug("modename=%s" % (modename))
             # toolbar follows view
             self.w.btn_pan.set_state(modename == 'pan')
-            self.w.btn_freepan.set_state(modename == 'freepan')
+            self.w.btn_zoom.set_state(modename == 'zoom')
             self.w.btn_rotate.set_state(modename == 'rotate')
             self.w.btn_dist.set_state(modename == 'dist')
             self.w.btn_cuts.set_state(modename == 'cuts')
             self.w.btn_contrast.set_state(modename == 'contrast')
+            self.w.btn_cmap.set_state(modename == 'cmap')
 
             default_mode_type = bm.get_default_mode_type()
             if 'btn_modelock' in self.w:
