@@ -13,6 +13,18 @@ import urllib.parse
 import tempfile
 
 from ginga.misc import Bunch
+from ginga.util.paths import ginga_home, ginga_pkgdir
+
+# load local mime types overrides, if present
+ginga_mimetypes = os.path.join(ginga_pkgdir,
+                               "examples", "configs", "mime.types")
+if os.path.exists(ginga_mimetypes):
+    mimetypes.init(files=[ginga_mimetypes])
+
+local_mimetypes = os.path.join(ginga_home, "mime.types")
+if os.path.exists(local_mimetypes):
+    mimetypes.init(files=[local_mimetypes])
+
 
 magic_tester = None
 try:
@@ -20,15 +32,15 @@ try:
     have_magic = True
     # it seems there are conflicting versions of a 'magic'
     # module for python floating around...*sigh*
+    # (python-magic vs. filemagic)
     if not hasattr(magic, 'from_file'):
-        # TODO: do this at program start only
-        magic_tester = magic.open(magic.DEFAULT_MODE)
+        # filemagic
+        magic_tester = magic.open(magic.MAGIC_MIME)
         magic_tester.load()
 
 except (ImportError, Exception):
     have_magic = False
 
-
 # NOTE: this is a shortcut list of extensions in which we trust the
 # extension over the mimetype that might be returned by the Python
 # 'mimetypes' module.  You can add an extension here if the loaders
@@ -41,6 +53,7 @@ known_types = {
     '.asdf': 'image/asdf',
     '.jpg': 'image/jpeg',
     '.jpeg': 'image/jpeg',
+    '.tif': 'image/tiff',
     '.tiff': 'image/tiff',
     '.gif': 'image/gif',
     '.png': 'image/png',
@@ -67,15 +80,18 @@ def guess_filetype(filepath):
             # it seems there are conflicting versions of a 'magic'
             # module for python floating around...*sigh*
             if hasattr(magic, 'from_file'):
+                # python-magic
                 typ = magic.from_file(filepath, mime=True)
 
             elif magic_tester is not None:
-                descrip = magic_tester.file(filepath)
-                if descrip.startswith("FITS image data"):
-                    return ('image', 'fits')
+                # filemagic
+                typ = magic_tester.file(filepath)
+
+            if isinstance(typ, str) and ';' in typ:
+                typ, enc = typ.split(';')
 
         except Exception as e:
-            pass
+            typ = None
 
     if typ is None:
         # if no magic, or magic fails, fall back to mimetypes
